@@ -114,21 +114,6 @@ Q_OBJECT
         void updateCursor();
 
     public slots:
-        void errorMessage( const QString & message, int duration = -1 )
-        {
-            displayMessage( message, QString(), PageViewMessage::Error, duration );
-        }
-
-        void noticeMessage( const QString & message, int duration = -1 )
-        {
-            displayMessage( message, QString(), PageViewMessage::Info, duration );
-        }
-
-        void warningMessage( const QString & message, int duration = -1 )
-        {
-            displayMessage( message, QString(), PageViewMessage::Warning, duration );
-        }
-
         void copyTextSelection() const;
         void selectAll();
 
@@ -174,6 +159,8 @@ Q_OBJECT
         void guessTableDividers();
         // update either text or rectangle selection
         void updateSelection( const QPoint & pos );
+        // compute the zoom factor value for FitWidth and FitPage mode
+        double zoomFactorFitMode( ZoomMode mode );
         // update internal zoom values and end in a slotRelayoutPages();
         void updateZoom( ZoomMode newZm );
         // update the text on the label using global zoom value or current page's one
